@@ -66,7 +66,7 @@ class Mooi:
 		else:
 			os.system("cls")
 		i = index
-		choices = ['0']
+		choices = ['q','0']
 		print self.HDR
 		print "-------------------"
 		print '(0) quit'
@@ -97,7 +97,7 @@ class Mooi:
 				if ((last < 0) or (last > len(list))):
 					last = 0
 				choices = self.show_choices(list, last)
-		if (choice == '0'):
+		if (choice in ['0','q']):
 			self.exit(" ",0)
 		else:	
 			choice = int(choice)-1
@@ -142,7 +142,10 @@ class Mooi:
 				lists[i].sort(self.compThird)
 				for entry in lists[i]:
 					tokens = string.split(entry,':')
-					self.tests.remove(tokens[0])
+					try:
+						self.tests.remove(tokens[0])
+					except:
+						pass
 					if ((tokens[1].find('*SCORE*') != -1) and
 						(float(tokens[2]) >= 90.0)):
 						continue
@@ -245,19 +248,16 @@ class Mooi:
 		f.close()
 		lines = self.purge(lines)
 		# get bsd file choice
-		print "(Available quizzes - 'q' to quit)"
 		choice = self.query(lines, 'Enter quiz number: ')
 		tokens = string.split(lines[choice],':')
 		self.quiz.append(tokens[0])		
 		# get question field
 		tokens = tokens[1:]
-		print "(Available fields)"
 		choice = self.query(tokens, 'Choose question field: ')
 		self.quiz.append(choice)
 		self.prevUsrChoice = choice
 		# set answer field
 		if (len(tokens) > 2):
-			print "(Available fields)"
 			choice = self.query(tokens, 'Choose answer field: ')
 			self.quiz.append(choice)
 		else:
